"""
FileManager V2 Scaffold - File operations with automatic linting via context hooks.

Architecture:
- BaseXMLScaffold with FileBlock XMLComponents
- Plugin system for extensible linting/processing
- Context lifecycle hooks for automatic linting
- 6 error display modes
"""

from .scaffold import FileManagerScaffold
from .models import FileBlock, FileManagerState, LintIssue, LintResults
from .tree_generation import TreeGenerator
from .error_display import ErrorFormatter, ErrorDisplayMode

# Import builtin plugins to register them
from .plugins.builtin import PyrightLinterPlugin

__all__ = [
    'FileManagerScaffold',
    'FileBlock',
    'FileManagerState',
    'LintIssue',
    'LintResults',
    'TreeGenerator',
    'ErrorFormatter',
    'ErrorDisplayMode',
    'PyrightLinterPlugin',
]
