"""
Plugin system for FileManager V2.

Architecture:
- BasePlugin: Base for ALL FileManager plugins
- LinterPlugin: Base for linting/type checking plugins
- PluginManager: Auto-discovery and dependency resolution
"""

from .base import BasePlugin, LinterPlugin
from .plugin_manager import PluginManager

__all__ = [
    'BasePlugin',
    'LinterPlugin',
    'PluginManager',
]
